@@ -967,7 +967,7 @@ static NSMutableArray *zoneList = nil;
                 [fileContents setObject:[archiver archiverData] forKey:@"Data"];
             }
 
-            /* converting dictionary to string needs a lot lot of memory !! */
+            /* FIXME: converting dictionary to string needs a lot lot of memory !! */
             savedOk = [fileContents writeToFile:filename atomically:YES];
             haveSavedDocument = savedOk;
 
@@ -1518,8 +1518,14 @@ static NSMutableArray *zoneList = nil;
     NSPrintPanel	*pp;
     NSPrintInfo		*pi;
 
+    /* FIXME: GNUstep printing needs to be fixed for the code below */
+#ifdef GNUSTEP_BASE_VERSION
+    op = [NSPrintOperation printOperationWithView:[self documentView] printInfo:printInfo];
+    [op setShowPanels:YES];
+    [op runOperation];
+#else
     if (![printInfo printer] && [NSPrintInfo defaultPrinter])
-        [printInfo setPrinter:[NSPrintInfo defaultPrinter]]; // set default printer for the first time
+        [printInfo setPrinter:[NSPrintInfo defaultPrinter]];	// set default printer for the first time
 
     op = [NSPrintOperation printOperationWithView:[self documentView] printInfo:printInfo];
     [op setShowPanels:YES];
@@ -1531,21 +1537,22 @@ static NSMutableArray *zoneList = nil;
 
     if ([pp runModal] == NSCancelButton)
     {
-        [op setShowPanels:NO]; // else the user get a second printpanel
-        [op runOperation]; // this will end the operation !
+        [op setShowPanels:NO];	// else the user get a second printpanel
+        [op runOperation];	// this will end the operation !
     }
-    else if (![[(App*)NSApp ppaRadio] selectedRow]) // composite
+    else if (![[(App*)NSApp ppaRadio] selectedRow])		// composite
     {
-        [op setShowPanels:NO]; // else the user get a second printpanel
+        [op setShowPanels:NO];	// else the user get a second printpanel
         [op runOperation];
     }
-    else // color separation
-    {   [[(App*)NSApp ppaRadio] selectCellAtRow:0 column:0];// 0 is composite 
+    else							// color separation
+    {   [[(App*)NSApp ppaRadio] selectCellAtRow:0 column:0];	// 0 is composite 
         [self printSeparation:op];
     }
     pi = [op printInfo];
     if ([pi printer])
-        [printInfo setPrinter:[pi printer]]; // notice printer for the next time !
+        [printInfo setPrinter:[pi printer]];	// remember printer for the next time !
+#endif
 }
 
 /*
